#
# This file is part of Plinth.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

"""
Plinth module for monkeysphere.
"""

from django.utils.translation import ugettext_lazy as _

from plinth import cfg

version = 1

depends = ['system']

title = _('Monkeysphere')

description = [
    _('With Monkeysphere, a PGP key can be generated for each configured '
      'domain serving SSH. The PGP public key can then be uploaded to the PGP '
      'keyservers. Users connecting to this machine through SSH can verify '
      'that they are connecting to the correct host.  For users to trust the '
      'key, at least one person (usually the machine owner) must sign the key '
      'using the regular PGP key signing process.  See the '
      '<a href="http://web.monkeysphere.info/getting-started-ssh/"> '
      'Monkeysphere SSH documentation</a> for more details.')
]


def init():
    """Initialize the monkeysphere module."""
    menu = cfg.main_menu.get('system:index')
    menu.add_urlname(_('Monkeysphere'), 'glyphicon-certificate',
                     'monkeysphere:index', 970)


def setup(helper, old_version=None):
    """Install and configure the module."""
    helper.install(['monkeysphere'])
